==> web-s-0.0.30.tgz: package/bin/library.js <==
#!/usr/bin/env node
'use strict';

var _open = require('open');

var _open2 = _interopRequireDefault(_open);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CONFIG_FILE = process.env.HOME + '/.web-s.conf';

var initConfig = {
  google: {
    url: 'https://www.google.com/search?q=',
    shortHand: 'default'
  },
  twitter: {
    url: 'https://twitter.com/search?src=typd&q=%23',
    shortHand: 't'
  },
  reddit: {
    url: 'https://www.reddit.com/search?q=',
    shortHand: 'r'
  },
  stackoverflow: {
    url: 'http://stackoverflow.com/search?q=',
    shortHand: 's'
  },
  leo: {
    url: 'http://dict.leo.org/ende/index_de.html#/search=',
    shortHand: 'l'
  }
};

/**
 * list all available providers
 * @param  {String} space the space in front of the output
 * @return {void}
 */
function listProviders(space) {
  Object.keys(searchEngines).map(function (provider) {
    return searchEngines[provider].shortHand === 'default' ? '' + space + provider + ' (default)' : '' + space + provider + ': -' + searchEngines[provider].shortHand + '/--' + provider;
  }).forEach(function (line) {
    return console.log(line);
  });
}

/**
 * prints the usage and optional an error
 * @param  {string} err the error to print
 * @return {void}
 */
function printUsage(err) {
  if (err) {
    console.error('ERROR:', err);
  }
  console.log('USAGE: web-s [provider] <searchstring>');
  console.log('Available providers:');
  listProviders('  ');
}

/**
 * joins the arguments dependent on the provider and opens the default webbrowser
 * @param  {object} provider
 * @param  {array} args the cli arguments
 * @return {Boolean}
 */
function openBrowser(provider, args) {
  var url = 0;

  if (provider.shortHand === 'default') {
    url = provider.url + args.join(' ');
  } else {
    url = provider.url + args.slice(1).join(' ');
  }

  if (url) {
    (0, _open2.default)(url);
  }

  return true;
}

/**
 * Parses the arguments and invokes the needed functions
 * @param  {Array} args the arguments
 * @return {void}
 */
function parseArguments(args) {
  switch (args[0]) {
    case '--generate-config':
      generateNewConfig();break;
    case '--list':
      listProviders('');break;
    case '-h':
    case '--help':
      printUsage();break;
    default:
      detetermineProvider(args);
  }
}

/**
 * checks with provider should be used
 * @param  {Array} args
 * @return {void}
 */
function detetermineProvider(args) {
  var opened = false;
  var defaultProvider = false;

  Object.keys(searchEngines).forEach(function (provider) {
    if ('-' + searchEngines[provider].shortHand === args[0] || '--' + provider === args[0]) {
      opened = openBrowser(searchEngines[provider], args);
    }
    if ('' + searchEngines[provider].shortHand === 'default') {
      defaultProvider = provider;
    }
  });

  if (!opened) {
    openBrowser(searchEngines[defaultProvider], args);
  }
}

/**
 * Generates a new config-file
 * @return {void}
 */
function generateNewConfig() {
  if (configExist()) {
    _fs2.default.unlinkSync(CONFIG_FILE);
  }

  createInitConfig();
}

/**
 * checks if a config exists
 * @return {Boolean}
 */
function configExist() {
  var fileExist = false;
  try {
    fileExist = _fs2.default.statSync(CONFIG_FILE).isFile();
  } finally {
    return fileExist;
  }
}

/**
 * creates a sample config
 * @return {void}
 */
function createInitConfig() {
  var config = JSON.stringify(initConfig, null, 2);
  _fs2.default.writeFile(CONFIG_FILE, config);
}

/**
 * reads the config file
 * @return {Object}
 */
function readConfig() {
  return JSON.parse(_fs2.default.readFileSync(CONFIG_FILE, 'utf8'));
}

var searchEngines = undefined;

if (!configExist()) {
  createInitConfig();
  searchEngines = initConfig;
} else {
  searchEngines = readConfig();
}

if (process.argv.length >= 3) {
  parseArguments(process.argv.slice(2));
} else {
  printUsage('No searchstring');
}

==> web-s-1.0.0.tgz: package/bin/library.js <==
#!/usr/bin/env node
'use strict';

var _open = require('open');

var _open2 = _interopRequireDefault(_open);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CONFIG_FILE = process.env.HOME + '/.web-s.conf';

var initConfig = {
  google: {
    url: 'https://www.google.com/search?q=%HERE%',
    shortHand: 'default'
  },
  twitter: {
    url: 'https://twitter.com/search?src=typd&q=%23%HERE%',
    shortHand: 't'
  },
  reddit: {
    url: 'https://www.reddit.com/search?q=%HERE%',
    shortHand: 'r'
  },
  stackoverflow: {
    url: 'http://stackoverflow.com/search?q=%HERE%',
    shortHand: 's'
  },
  leo: {
    url: 'http://dict.leo.org/ende/index_de.html#/search=%HERE%',
    shortHand: 'l'
  }
};

/**
 * list all available providers
 * @param  {String} space the space in front of the output
 * @return {void}
 */
function listProviders(space) {
  Object.keys(searchEngines).map(function (provider) {
    return searchEngines[provider].shortHand === 'default' ? '' + space + provider + ' (default)' : '' + space + provider + ': -' + searchEngines[provider].shortHand + '/--' + provider;
  }).forEach(function (line) {
    return console.log(line);
  });
}

/**
 * prints the usage and optional an error
 * @param  {string} err the error to print
 * @return {void}
 */
function printUsage(err) {
  if (err) {
    console.error('ERROR:', err);
  }
  console.log('USAGE: web-s [provider] <searchstring>');
  console.log('Available providers:');
  listProviders('  ');
}

/**
 * joins the arguments dependent on the provider and opens the default webbrowser
 * @param  {object} provider
 * @param  {array} args the cli arguments
 * @return {Boolean}
 */
function openBrowser(provider, args) {
  var url = 0;

  if (provider.shortHand === 'default') {
    url = provider.url.replace('%HERE%', args.join(' '));
  } else {
    url = provider.url.replace('%HERE%', args.slice(1).join(' '));
  }

  if (url) {
    (0, _open2.default)(url);
  }

  return true;
}

/**
 * Parses the arguments and invokes the needed functions
 * @param  {Array} args the arguments
 * @return {void}
 */
function parseArguments(args) {
  switch (args[0]) {
    case '--generate-config':
      generateNewConfig();break;
    case '--list':
      listProviders('');break;
    case '-h':
    case '--help':
      printUsage();break;
    default:
      detetermineProvider(args);
  }
}

/**
 * checks with provider should be used
 * @param  {Array} args
 * @return {void}
 */
function detetermineProvider(args) {
  var opened = false;
  var defaultProvider = false;

  Object.keys(searchEngines).forEach(function (provider) {
    if ('-' + searchEngines[provider].shortHand === args[0] || '--' + provider === args[0]) {
      opened = openBrowser(searchEngines[provider], args);
    }
    if ('' + searchEngines[provider].shortHand === 'default') {
      defaultProvider = provider;
    }
  });

  if (!opened) {
    openBrowser(searchEngines[defaultProvider], args);
  }
}

/**
 * Generates a new config-file
 * @return {void}
 */
function generateNewConfig() {
  if (configExist()) {
    _fs2.default.unlinkSync(CONFIG_FILE);
  }

  createInitConfig();
}

/**
 * checks if a config exists
 * @return {Boolean}
 */
function configExist() {
  var fileExist = false;
  try {
    fileExist = _fs2.default.statSync(CONFIG_FILE).isFile();
  } finally {
    return fileExist;
  }
}

/**
 * creates a sample config
 * @return {void}
 */
function createInitConfig() {
  var config = JSON.stringify(initConfig, null, 2);
  _fs2.default.writeFile(CONFIG_FILE, config);
}

/**
 * reads the config file
 * @return {Object}
 */
function readConfig() {
  return JSON.parse(_fs2.default.readFileSync(CONFIG_FILE, 'utf8'));
}

var searchEngines = undefined;

if (!configExist()) {
  createInitConfig();
  searchEngines = initConfig;
} else {
  searchEngines = readConfig();
}

if (process.argv.length >= 3) {
  parseArguments(process.argv.slice(2));
} else {
  printUsage('No searchstring');
}
